summaryrefslogtreecommitdiff
path: root/board/lindar/board.c
diff options
context:
space:
mode:
Diffstat (limited to 'board/lindar/board.c')
-rw-r--r--board/lindar/board.c24
1 files changed, 12 insertions, 12 deletions
diff --git a/board/lindar/board.c b/board/lindar/board.c
index 8168b9c51a..c65421b08b 100644
--- a/board/lindar/board.c
+++ b/board/lindar/board.c
@@ -250,18 +250,18 @@ const struct fan_t fans[FAN_CH_COUNT] = {
/*
* Tiger Lake specifies 100 C as maximum TDP temperature. THRMTRIP# occurs at
* 130 C. However, sensor is located next to DDR, so we need to use the lower
* DDR temperature limit (85 C)
*/
const static struct ec_thermal_config thermal_cpu = {
.temp_host = {
- [EC_TEMP_THRESH_HIGH] = C_TO_K(70),
- [EC_TEMP_THRESH_HALT] = C_TO_K(80),
+ [EC_TEMP_THRESH_HIGH] = C_TO_K(90),
+ [EC_TEMP_THRESH_HALT] = C_TO_K(100),
},
.temp_host_release = {
- [EC_TEMP_THRESH_HIGH] = C_TO_K(65),
+ [EC_TEMP_THRESH_HIGH] = C_TO_K(85),
},
- .temp_fan_off = C_TO_K(35),
- .temp_fan_max = C_TO_K(50),
+ .temp_fan_off = C_TO_K(30),
+ .temp_fan_max = C_TO_K(60),
};
/*
@@ -273,18 +273,18 @@ const static struct ec_thermal_config thermal_cpu = {
* PP3300 regulator: operating range -40 C to 145 C
*
* Inductors: limit of 125c
* PCB: limit is 80c
*/
const static struct ec_thermal_config thermal_inductor = {
.temp_host = {
- [EC_TEMP_THRESH_HIGH] = C_TO_K(75),
- [EC_TEMP_THRESH_HALT] = C_TO_K(80),
+ [EC_TEMP_THRESH_HIGH] = C_TO_K(90),
+ [EC_TEMP_THRESH_HALT] = C_TO_K(100),
},
.temp_host_release = {
- [EC_TEMP_THRESH_HIGH] = C_TO_K(65),
+ [EC_TEMP_THRESH_HIGH] = C_TO_K(85),
},
- .temp_fan_off = C_TO_K(40),
- .temp_fan_max = C_TO_K(55),
+ .temp_fan_off = C_TO_K(30),
+ .temp_fan_max = C_TO_K(60),
};
@@ -250,18 +250,18 @@ const struct fan_t fans[FAN_CH_COUNT] = {
* Tiger Lake specifies 100 C as maximum TDP temperature. THRMTRIP# occurs at
* 130 C. However, sensor is located next to DDR, so we need to use the lower
- * DDR temperature limit (85 C)
+ * DDR temperature limit (100 C)
*/
const static struct ec_thermal_config thermal_cpu = {
@@ -273,18 +273,18 @@ const static struct ec_thermal_config thermal_cpu = {
*
* Inductors: limit of 125c
- * PCB: limit is 80c
+ * PCB: limit is 100c
*/
const static struct ec_thermal_config thermal_inductor = {